@@ -3,7 +3,7 @@
  * NAGIOS.C - Core Program Code For Nagios
  *
  * Program: Nagios Core
- * Version: 3.5.1
+ * Version: 3.5.0
  * License: GPL
  * Copyright (c) 2009-2010 Nagios Core Development Team and Community Contributors
  * Copyright (c) 1999-2009 Ethan Galstad
@@ -438,12 +438,6 @@ int main(int argc, char **argv, char **env) {
 		exit(ERROR);
 		}
 
-	/*
-	 * Set the signal handler for the SIGXFSZ signal here because
-	 * we may encounter this signal before the other signal handlers
-	 * are set.
-	 */
-	signal(SIGXFSZ, handle_sigxfsz);                                            
 
 	/* config file is last argument specified */
 	config_file = (char *)strdup(argv[optind]);
